from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtCls:
	"""Rt commands group definition. 31 total commands, 9 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rt", core, parent)

	@property
	def beidou(self):
		"""beidou commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_beidou'):
			from .Beidou import BeidouCls
			self._beidou = BeidouCls(self._core, self._cmd_group)
		return self._beidou

	@property
	def galileo(self):
		"""galileo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_galileo'):
			from .Galileo import GalileoCls
			self._galileo = GalileoCls(self._core, self._cmd_group)
		return self._galileo

	@property
	def glonass(self):
		"""glonass commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_glonass'):
			from .Glonass import GlonassCls
			self._glonass = GlonassCls(self._core, self._cmd_group)
		return self._glonass

	@property
	def gps(self):
		"""gps commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_gps'):
			from .Gps import GpsCls
			self._gps = GpsCls(self._core, self._cmd_group)
		return self._gps

	@property
	def navic(self):
		"""navic commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_navic'):
			from .Navic import NavicCls
			self._navic = NavicCls(self._core, self._cmd_group)
		return self._navic

	@property
	def qzss(self):
		"""qzss commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_qzss'):
			from .Qzss import QzssCls
			self._qzss = QzssCls(self._core, self._cmd_group)
		return self._qzss

	@property
	def receiver(self):
		"""receiver commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_receiver'):
			from .Receiver import ReceiverCls
			self._receiver = ReceiverCls(self._core, self._cmd_group)
		return self._receiver

	@property
	def sbas(self):
		"""sbas commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbas'):
			from .Sbas import SbasCls
			self._sbas = SbasCls(self._core, self._cmd_group)
		return self._sbas

	@property
	def stream(self):
		"""stream commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_stream'):
			from .Stream import StreamCls
			self._stream = StreamCls(self._core, self._cmd_group)
		return self._stream

	def get_hdop(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:HDOP \n
		Snippet: value: float = driver.source.bb.gnss.rt.get_hdop() \n
		Queries the horizontal dilution of precision (HDOP) value of the selected satellite constellation. \n
			:return: realtime_hdop: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RT:HDOP?')
		return Conversions.str_to_float(response)

	def get_hw_time(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:HWTime \n
		Snippet: value: float = driver.source.bb.gnss.rt.get_hw_time() \n
		Queries the time elapsed since the simulation start. To query the simulation start time, use the command:
		[:SOURce<hw>]:BB:GNSS:TIME:STARt:TIME. \n
			:return: elapsed_time: float Range: 0 to max, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RT:HWTime?')
		return Conversions.str_to_float(response)

	def get_pdop(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:PDOP \n
		Snippet: value: float = driver.source.bb.gnss.rt.get_pdop() \n
		Queries the position dilution of precision (PDOP) value of the selected satellite constellation. \n
			:return: realtime_pdop: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RT:PDOP?')
		return Conversions.str_to_float(response)

	def get_vdop(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:VDOP \n
		Snippet: value: float = driver.source.bb.gnss.rt.get_vdop() \n
		Queries the vertical dilution of precision (VDOP) value of the selected satellite constellation. \n
			:return: realtime_vdop: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:RT:VDOP?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'RtCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RtCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McbGroupsCls:
	"""McbGroups commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mcbGroups", core, parent)

	def set(self, dl_max_cbg_per_tb: enums.MaxCbgaLl, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:MCBGroups \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.mcbGroups.set(dl_max_cbg_per_tb = enums.MaxCbgaLl.DISabled, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Limits the number of code block groups per transport block. In 5G NR a huge TB (transport block) is split into multiple
		code blocks (CB) . Multiples CBs are grouped into one code block group (CBG) . The number of code blocks grouped into the
		CBG can be limited by the 'Max Code Block Groups Per Transport Block' setting. \n
			:param dl_max_cbg_per_tb: G2| G4| DISabled| G6| G8 G2 Limits the number of code block groups per transport block to 2. G4 Limits the number of code block groups per transport block to 4. G6 Limits the number of code block groups per transport block to 6. G8 Limits the number of code block groups per transport block to 8. DISabled Default value (also G0) , which disabled the limitation of code block groups per transport block.
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.enum_scalar_to_str(dl_max_cbg_per_tb, enums.MaxCbgaLl)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:MCBGroups {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> enums.MaxCbgaLl:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:MCBGroups \n
		Snippet: value: enums.MaxCbgaLl = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.mcbGroups.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Limits the number of code block groups per transport block. In 5G NR a huge TB (transport block) is split into multiple
		code blocks (CB) . Multiples CBs are grouped into one code block group (CBG) . The number of code blocks grouped into the
		CBG can be limited by the 'Max Code Block Groups Per Transport Block' setting. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: dl_max_cbg_per_tb: G2| G4| DISabled| G6| G8 G2 Limits the number of code block groups per transport block to 2. G4 Limits the number of code block groups per transport block to 4. G6 Limits the number of code block groups per transport block to 6. G8 Limits the number of code block groups per transport block to 8. DISabled Default value (also G0) , which disabled the limitation of code block groups per transport block."""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:MCBGroups?')
		return Conversions.str_to_scalar_enum(response, enums.MaxCbgaLl)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PparameterCls:
	"""Pparameter commands group definition. 5 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pparameter", core, parent)

	@property
	def dpch(self):
		"""dpch commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_dpch'):
			from .Dpch import DpchCls
			self._dpch = DpchCls(self._core, self._cmd_group)
		return self._dpch

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	@property
	def pccpch(self):
		"""pccpch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pccpch'):
			from .Pccpch import PccpchCls
			self._pccpch = PccpchCls(self._core, self._cmd_group)
		return self._pccpch

	def clone(self) -> 'PparameterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PparameterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NpatternCls:
	"""Npattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("npattern", core, parent)

	def set(self, notif_pattern: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:AI:MCCH:NPATtern \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.ai.mcch.npattern.set(notif_pattern = rawAbc, bitcount = 1) \n
		Sets the pattern for the notification bits sent on PDCCH DCI format 1c. \n
			:param notif_pattern: numeric
			:param bitcount: integer Range: 1 to 64
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('notif_pattern', notif_pattern, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:AI:MCCH:NPATtern {param}'.rstrip())

	# noinspection PyTypeChecker
	class NpatternStruct(StructBase):
		"""Response structure. Fields: \n
			- Notif_Pattern: str: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Notif_Pattern'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Notif_Pattern: str = None
			self.Bitcount: int = None

	def get(self) -> NpatternStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:AI:MCCH:NPATtern \n
		Snippet: value: NpatternStruct = driver.source.bb.eutra.downlink.mbsfn.ai.mcch.npattern.get() \n
		Sets the pattern for the notification bits sent on PDCCH DCI format 1c. \n
			:return: structure: for return value, see the help for NpatternStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:AI:MCCH:NPATtern?', self.__class__.NpatternStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, sec_pass_word: str, state: bool) -> None:
		"""SCPI: DISPlay:ANNotation:FREQuency \n
		Snippet: driver.display.annotation.frequency.set(sec_pass_word = 'abc', state = False) \n
		Indicates asterisks instead of the frequency values in the status bar. \n
			:param sec_pass_word: No help available
			:param state: 1| ON| 0| OFF
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sec_pass_word', sec_pass_word, DataType.String), ArgSingle('state', state, DataType.Boolean))
		self._core.io.write(f'DISPlay:ANNotation:FREQuency {param}'.rstrip())

	# noinspection PyTypeChecker
	class FrequencyStruct(StructBase):
		"""Response structure. Fields: \n
			- Sec_Pass_Word: str: No parameter help available
			- State: bool: 1| ON| 0| OFF"""
		__meta_args_list = [
			ArgStruct.scalar_str('Sec_Pass_Word'),
			ArgStruct.scalar_bool('State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Sec_Pass_Word: str = None
			self.State: bool = None

	def get(self) -> FrequencyStruct:
		"""SCPI: DISPlay:ANNotation:FREQuency \n
		Snippet: value: FrequencyStruct = driver.display.annotation.frequency.get() \n
		Indicates asterisks instead of the frequency values in the status bar. \n
			:return: structure: for return value, see the help for FrequencyStruct structure arguments."""
		return self._core.io.query_struct(f'DISPlay:ANNotation:FREQuency?', self.__class__.FrequencyStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DirectCls:
	"""Direct commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("direct", core, parent)

	def set(self, command: str, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:DIRect \n
		Snippet: driver.sense.power.direct.set(command = 'abc', channel = repcap.Channel.Default) \n
		No command help available \n
			:param command: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.value_to_quoted_str(command)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:DIRect {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddCls:
	"""Add commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("add", core, parent)

	def set(self, instr_name: str, hw_chan: str, tcp_ipor_usb_addr: str, rf_path_number: str = None) -> None:
		"""SCPI: SCONfiguration:EXTernal:REMote:ADD \n
		Snippet: driver.sconfiguration.external.remote.add.set(instr_name = 'abc', hw_chan = 'abc', tcp_ipor_usb_addr = 'abc', rf_path_number = 'abc') \n
		Adds manually an external instrument to the list of available instruments. \n
			:param instr_name: String Alias name of the instrument
			:param hw_chan: String Hardware channel (USB or LAN) used by the remote channel to the external instrument Range: 'LAN' to 'USB'
			:param tcp_ipor_usb_addr: String IP address or hostname of the connected external instrument
			:param rf_path_number: String Determines the number of RF paths the external instrument is equipped with Range: '1' to '2'
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('instr_name', instr_name, DataType.String), ArgSingle('hw_chan', hw_chan, DataType.String), ArgSingle('tcp_ipor_usb_addr', tcp_ipor_usb_addr, DataType.String), ArgSingle('rf_path_number', rf_path_number, DataType.String, None, is_optional=True))
		self._core.io.write(f'SCONfiguration:EXTernal:REMote:ADD {param}'.rstrip())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxbwCls:
	"""Txbw commands group definition. 22 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("txbw", core, parent)

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import ConflictCls
			self._conflict = ConflictCls(self._core, self._cmd_group)
		return self._conflict

	@property
	def pointA(self):
		"""pointA commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pointA'):
			from .PointA import PointACls
			self._pointA = PointACls(self._core, self._cmd_group)
		return self._pointA

	@property
	def resolve(self):
		"""resolve commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resolve'):
			from .Resolve import ResolveCls
			self._resolve = ResolveCls(self._core, self._cmd_group)
		return self._resolve

	@property
	def s120K(self):
		"""s120K commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_s120K'):
			from .S120K import S120KCls
			self._s120K = S120KCls(self._core, self._cmd_group)
		return self._s120K

	@property
	def s15K(self):
		"""s15K commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_s15K'):
			from .S15K import S15KCls
			self._s15K = S15KCls(self._core, self._cmd_group)
		return self._s15K

	@property
	def s240K(self):
		"""s240K commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_s240K'):
			from .S240K import S240KCls
			self._s240K = S240KCls(self._core, self._cmd_group)
		return self._s240K

	@property
	def s30K(self):
		"""s30K commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_s30K'):
			from .S30K import S30KCls
			self._s30K = S30KCls(self._core, self._cmd_group)
		return self._s30K

	@property
	def s480K(self):
		"""s480K commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_s480K'):
			from .S480K import S480KCls
			self._s480K = S480KCls(self._core, self._cmd_group)
		return self._s480K

	@property
	def s60K(self):
		"""s60K commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_s60K'):
			from .S60K import S60KCls
			self._s60K = S60KCls(self._core, self._cmd_group)
		return self._s60K

	@property
	def s960K(self):
		"""s960K commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_s960K'):
			from .S960K import S960KCls
			self._s960K = S960KCls(self._core, self._cmd_group)
		return self._s960K

	def clone(self) -> 'TxbwCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TxbwCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 12 total commands, 5 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	@property
	def afixed(self):
		"""afixed commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_afixed'):
			from .Afixed import AfixedCls
			self._afixed = AfixedCls(self._core, self._cmd_group)
		return self._afixed

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def protection(self):
		"""protection commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_protection'):
			from .Protection import ProtectionCls
			self._protection = ProtectionCls(self._core, self._cmd_group)
		return self._protection

	@property
	def user(self):
		"""user commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .User import UserCls
			self._user = UserCls(self._core, self._cmd_group)
		return self._user

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	# noinspection PyTypeChecker
	def get_amode(self) -> enums.PowAttMode:
		"""SCPI: OUTPut<HW>:AMODe \n
		Snippet: value: enums.PowAttMode = driver.output.get_amode() \n
		Sets the step attenuator mode at the RF output. \n
			:return: amode: AUTO| FIXed AUTO The step attenuator adjusts the level settings automatically, within the full variation range. FIXed The step attenuator and amplifier stages are fixed at the current position, providing level settings with constant output VSWR. The resulting variation range is calculated according to the position.
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:AMODe?')
		return Conversions.str_to_scalar_enum(response, enums.PowAttMode)

	def set_amode(self, amode: enums.PowAttMode) -> None:
		"""SCPI: OUTPut<HW>:AMODe \n
		Snippet: driver.output.set_amode(amode = enums.PowAttMode.AUTO) \n
		Sets the step attenuator mode at the RF output. \n
			:param amode: AUTO| FIXed AUTO The step attenuator adjusts the level settings automatically, within the full variation range. FIXed The step attenuator and amplifier stages are fixed at the current position, providing level settings with constant output VSWR. The resulting variation range is calculated according to the position.
		"""
		param = Conversions.enum_scalar_to_str(amode, enums.PowAttMode)
		self._core.io.write(f'OUTPut<HwInstance>:AMODe {param}')

	# noinspection PyTypeChecker
	def get_impedance(self) -> enums.InputImpRf:
		"""SCPI: OUTPut<HW>:IMPedance \n
		Snippet: value: enums.InputImpRf = driver.output.get_impedance() \n
		Queries the impedance of the RF outputs. \n
			:return: impedance: G1K| G50| G10K
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:IMPedance?')
		return Conversions.str_to_scalar_enum(response, enums.InputImpRf)

	def clone(self) -> 'OutputCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OutputCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tb1Cls:
	"""Tb1 commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tb1", core, parent)

	@property
	def mcs(self):
		"""mcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs'):
			from .Mcs import McsCls
			self._mcs = McsCls(self._core, self._cmd_group)
		return self._mcs

	@property
	def ndi(self):
		"""ndi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndi'):
			from .Ndi import NdiCls
			self._ndi = NdiCls(self._core, self._cmd_group)
		return self._ndi

	@property
	def rv(self):
		"""rv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rv'):
			from .Rv import RvCls
			self._rv = RvCls(self._core, self._cmd_group)
		return self._rv

	def clone(self) -> 'Tb1Cls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tb1Cls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClockCls:
	"""Clock commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clock", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbWaveSegmClocMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk:MODE \n
		Snippet: value: enums.ArbWaveSegmClocMode = driver.source.bb.arbitrary.wsegment.configure.clock.get_mode() \n
		Selects the clock rate mode for the multi segment waveform.
		Use the command [:SOURce<hw>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk to define the clock in clock mode user. \n
			:return: mode: UNCHanged| HIGHest| USER
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:CLOCk:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbWaveSegmClocMode)

	def set_mode(self, mode: enums.ArbWaveSegmClocMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk:MODE \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.clock.set_mode(mode = enums.ArbWaveSegmClocMode.HIGHest) \n
		Selects the clock rate mode for the multi segment waveform.
		Use the command [:SOURce<hw>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk to define the clock in clock mode user. \n
			:param mode: UNCHanged| HIGHest| USER
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbWaveSegmClocMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:CLOCk:MODE {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk \n
		Snippet: value: float = driver.source.bb.arbitrary.wsegment.configure.clock.get_value() \n
		Defines the clock rate used for multi-segment waveform output, if the clock mode is USER. \n
			:return: clock: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:CLOCk?')
		return Conversions.str_to_float(response)

	def set_value(self, clock: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:CLOCk \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.clock.set_value(clock = 1.0) \n
		Defines the clock rate used for multi-segment waveform output, if the clock mode is USER. \n
			:param clock: float
		"""
		param = Conversions.decimal_value_to_str(clock)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:CLOCk {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NavigationCls:
	"""Navigation commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("navigation", core, parent)

	def get_create(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:NAVigation:CREate \n
		Snippet: value: str = driver.source.bb.gnss.adGeneration.navigation.get_create() \n
		Saves the current assistance data settings into the selected navigation file. Assistance data settings are saved as
		navigation file with the specific file extensions *.rs_nav or into RINEX files with extension .10n. Refer to 'MMEMory
		Subsystem' for general information on file handling in the default and in a specific directory. \n
			:return: filename: string Filename or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:NAVigation:CREate?')
		return trim_str_response(response)

	def set_create(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:NAVigation:CREate \n
		Snippet: driver.source.bb.gnss.adGeneration.navigation.set_create(filename = 'abc') \n
		Saves the current assistance data settings into the selected navigation file. Assistance data settings are saved as
		navigation file with the specific file extensions *.rs_nav or into RINEX files with extension .10n. Refer to 'MMEMory
		Subsystem' for general information on file handling in the default and in a specific directory. \n
			:param filename: string Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:NAVigation:CREate {param}')

	# noinspection PyTypeChecker
	def get_dformat(self) -> enums.NavDataFormat:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:NAVigation:DFORmat \n
		Snippet: value: enums.NavDataFormat = driver.source.bb.gnss.adGeneration.navigation.get_dformat() \n
		Sets format of the generated navigation data file. \n
			:return: data_format: LNAV| CNAV
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:NAVigation:DFORmat?')
		return Conversions.str_to_scalar_enum(response, enums.NavDataFormat)

	def set_dformat(self, data_format: enums.NavDataFormat) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:NAVigation:DFORmat \n
		Snippet: driver.source.bb.gnss.adGeneration.navigation.set_dformat(data_format = enums.NavDataFormat.CNAV) \n
		Sets format of the generated navigation data file. \n
			:param data_format: LNAV| CNAV
		"""
		param = Conversions.enum_scalar_to_str(data_format, enums.NavDataFormat)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:NAVigation:DFORmat {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.WlannMarkMode, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:TRIGger:OUTPut<CH>:MODE \n
		Snippet: driver.source.bb.wlnn.trigger.output.mode.set(mode = enums.WlannMarkMode.FAPart, output = repcap.Output.Default) \n
		Defines the signal for the selected marker output. \n
			:param mode: RESTart| FBLock| FRAMe| FAPart| PULSe| PATTern| RATio| FIPart RESTart A marker signal is generated at the start of each signal sequence (period = all frame blocks) . FRAMe Number of Frame Blocks = 1, that is, a marker signal is generated at the start of each frame in the single frame block. Otherwise, the frame block and frame index are entered and the specific frame is masked. FBLock Number of Frame Blocks = 1, that is, a marker signal is generated at the start of each frame block. Otherwise, a specific frame block index is given and the whole frame block is marked. FAPart Number of Frame Blocks = 1, that is, a marker signal is generated to mark every active part of each frame. The active data transfer part (PPDU) of a frame period is marked with high, the inactive part (idle time) with low. This marker can be used to decrease the carrier leakage during inactive signal parts by feeding it into the pulse modulator. Otherwise, the frame block and frame index are entered and the active part of the specific frame is masked. PATTern A marker signal is generated according to the user defined pattern (command SOURce:BB:WLNN:TRIGger:OUTPut:PATTern) . PULSe A pulsed marker signal is generated. The pulse frequency (= symbol rate/divider) is defined with the SOUR:BB:WLNN:TRIG:OUTP:PULSe:DIVider command and can be queried with the SOUR:BB:WLNN:TRIG:OUTP:PULSe:FREQuency? command. RATio A marker signal corresponding to the Time Off / Time On specifications in the commands SOURce:BB:WLNN:TRIGger:OUTPut:OFFT and 'SOURce:BB:WLNN:TRIGger:OUTPut:ONT' is generated.
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.WlannMarkMode)
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:TRIGger:OUTPut{output_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, output=repcap.Output.Default) -> enums.WlannMarkMode:
		"""SCPI: [SOURce<HW>]:BB:WLNN:TRIGger:OUTPut<CH>:MODE \n
		Snippet: value: enums.WlannMarkMode = driver.source.bb.wlnn.trigger.output.mode.get(output = repcap.Output.Default) \n
		Defines the signal for the selected marker output. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: mode: RESTart| FBLock| FRAMe| FAPart| PULSe| PATTern| RATio| FIPart RESTart A marker signal is generated at the start of each signal sequence (period = all frame blocks) . FRAMe Number of Frame Blocks = 1, that is, a marker signal is generated at the start of each frame in the single frame block. Otherwise, the frame block and frame index are entered and the specific frame is masked. FBLock Number of Frame Blocks = 1, that is, a marker signal is generated at the start of each frame block. Otherwise, a specific frame block index is given and the whole frame block is marked. FAPart Number of Frame Blocks = 1, that is, a marker signal is generated to mark every active part of each frame. The active data transfer part (PPDU) of a frame period is marked with high, the inactive part (idle time) with low. This marker can be used to decrease the carrier leakage during inactive signal parts by feeding it into the pulse modulator. Otherwise, the frame block and frame index are entered and the active part of the specific frame is masked. PATTern A marker signal is generated according to the user defined pattern (command SOURce:BB:WLNN:TRIGger:OUTPut:PATTern) . PULSe A pulsed marker signal is generated. The pulse frequency (= symbol rate/divider) is defined with the SOUR:BB:WLNN:TRIG:OUTP:PULSe:DIVider command and can be queried with the SOUR:BB:WLNN:TRIG:OUTP:PULSe:FREQuency? command. RATio A marker signal corresponding to the Time Off / Time On specifications in the commands SOURce:BB:WLNN:TRIGger:OUTPut:OFFT and 'SOURce:BB:WLNN:TRIGger:OUTPut:ONT' is generated."""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:TRIGger:OUTPut{output_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.WlannMarkMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UinfoCls:
	"""Uinfo commands group definition. 16 total commands, 16 Subgroups, 0 group commands
	Repeated Capability: TriggerFrameUser, default value after init: TriggerFrameUser.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uinfo", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_triggerFrameUser_get', 'repcap_triggerFrameUser_set', repcap.TriggerFrameUser.Nr1)

	def repcap_triggerFrameUser_set(self, triggerFrameUser: repcap.TriggerFrameUser) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TriggerFrameUser.Default
		Default value after init: TriggerFrameUser.Nr1"""
		self._cmd_group.set_repcap_enum_value(triggerFrameUser)

	def repcap_triggerFrameUser_get(self) -> repcap.TriggerFrameUser:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def aid(self):
		"""aid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aid'):
			from .Aid import AidCls
			self._aid = AidCls(self._core, self._cmd_group)
		return self._aid

	@property
	def codType(self):
		"""codType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_codType'):
			from .CodType import CodTypeCls
			self._codType = CodTypeCls(self._core, self._cmd_group)
		return self._codType

	@property
	def dcm(self):
		"""dcm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dcm'):
			from .Dcm import DcmCls
			self._dcm = DcmCls(self._core, self._cmd_group)
		return self._dcm

	@property
	def mcs(self):
		"""mcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs'):
			from .Mcs import McsCls
			self._mcs = McsCls(self._core, self._cmd_group)
		return self._mcs

	@property
	def ps160(self):
		"""ps160 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ps160'):
			from .Ps160 import Ps160Cls
			self._ps160 = Ps160Cls(self._core, self._cmd_group)
		return self._ps160

	@property
	def pvi(self):
		"""pvi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pvi'):
			from .Pvi import PviCls
			self._pvi = PviCls(self._core, self._cmd_group)
		return self._pvi

	@property
	def rsv(self):
		"""rsv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsv'):
			from .Rsv import RsvCls
			self._rsv = RsvCls(self._core, self._cmd_group)
		return self._rsv

	@property
	def ruAllocation(self):
		"""ruAllocation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ruAllocation'):
			from .RuAllocation import RuAllocationCls
			self._ruAllocation = RuAllocationCls(self._core, self._cmd_group)
		return self._ruAllocation

	@property
	def sprFirst(self):
		"""sprFirst commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sprFirst'):
			from .SprFirst import SprFirstCls
			self._sprFirst = SprFirstCls(self._core, self._cmd_group)
		return self._sprFirst

	@property
	def sprSecond(self):
		"""sprSecond commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sprSecond'):
			from .SprSecond import SprSecondCls
			self._sprSecond = SprSecondCls(self._core, self._cmd_group)
		return self._sprSecond

	@property
	def ssAllocation(self):
		"""ssAllocation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssAllocation'):
			from .SsAllocation import SsAllocationCls
			self._ssAllocation = SsAllocationCls(self._core, self._cmd_group)
		return self._ssAllocation

	@property
	def tdUserInfo(self):
		"""tdUserInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdUserInfo'):
			from .TdUserInfo import TdUserInfoCls
			self._tdUserInfo = TdUserInfoCls(self._core, self._cmd_group)
		return self._tdUserInfo

	@property
	def trssi(self):
		"""trssi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trssi'):
			from .Trssi import TrssiCls
			self._trssi = TrssiCls(self._core, self._cmd_group)
		return self._trssi

	@property
	def ubExtension(self):
		"""ubExtension commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ubExtension'):
			from .UbExtension import UbExtensionCls
			self._ubExtension = UbExtensionCls(self._core, self._cmd_group)
		return self._ubExtension

	@property
	def udv(self):
		"""udv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_udv'):
			from .Udv import UdvCls
			self._udv = UdvCls(self._core, self._cmd_group)
		return self._udv

	@property
	def ureserved(self):
		"""ureserved commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ureserved'):
			from .Ureserved import UreservedCls
			self._ureserved = UreservedCls(self._core, self._cmd_group)
		return self._ureserved

	def clone(self) -> 'UinfoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UinfoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SsOffsetCls:
	"""SsOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ssOffset", core, parent)

	def set(self, search_space_offs: enums.EutraNbiotSearchSpaceOffset, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:NIOT:SSOFfset \n
		Snippet: driver.source.bb.eutra.downlink.user.niot.ssOffset.set(search_space_offs = enums.EutraNbiotSearchSpaceOffset.O0, userIx = repcap.UserIx.Default) \n
		Shifts the search space start. \n
			:param search_space_offs: O0| O1_8| O1_4| O3_8
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(search_space_offs, enums.EutraNbiotSearchSpaceOffset)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:NIOT:SSOFfset {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.EutraNbiotSearchSpaceOffset:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:NIOT:SSOFfset \n
		Snippet: value: enums.EutraNbiotSearchSpaceOffset = driver.source.bb.eutra.downlink.user.niot.ssOffset.get(userIx = repcap.UserIx.Default) \n
		Shifts the search space start. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: search_space_offs: O0| O1_8| O1_4| O3_8"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:NIOT:SSOFfset?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotSearchSpaceOffset)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BlerCls:
	"""Bler commands group definition. 18 total commands, 2 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bler", core, parent)

	@property
	def setup(self):
		"""setup commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_setup'):
			from .Setup import SetupCls
			self._setup = SetupCls(self._core, self._cmd_group)
		return self._setup

	@property
	def trigger(self):
		"""trigger commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	def load(self, filename: str) -> None:
		"""SCPI: BLER:LOAD \n
		Snippet: driver.bler.load(filename = 'abc') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.ber_bler Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory. \n
			:param filename: string Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'BLER:LOAD {param}')

	def preset(self) -> None:
		"""SCPI: BLER:PRESet \n
		Snippet: driver.bler.preset() \n
		Sets the parameters of the BERT/BLER test generator to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command .method RsSmbv.Bert.state/method RsSmbv.Bler.state. \n
		"""
		self._core.io.write(f'BLER:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BLER:PRESet \n
		Snippet: driver.bler.preset_with_opc() \n
		Sets the parameters of the BERT/BLER test generator to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command .method RsSmbv.Bert.state/method RsSmbv.Bler.state. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BLER:PRESet', opc_timeout_ms)

	# noinspection PyTypeChecker
	class ResultStruct(StructBase):  # From ReadStructDefinition CmdPropertyTemplate.xml
		"""Structure for reading output parameters. Fields: \n
			- Num_Block: int: integer Number of checked data bits.
			- Num_Errors: int: integer Number of error bits.
			- Error_Rate: float: float If no termination criterion has been reached since the beginning of the measurement, display the current quotient of NumErrors (number of error bits) and NumBlock (number of data bits) . When at least one final result has been reached in continuous measurement, display the most recent final result.
			- Meas_Finished: int: integer Status of measurement. 1 Measurement has been terminated, i.e. stopped or the defined number of data bits or error bits has been reached. 0 Measurement has not been terminated.
			- Clock_Detected: int: integer Status of clock line. 1 Clock line active. 0 Clock line not active.
			- Data_Detected: int: integer Status of data line. 1 Data line active. Only clocked data is detected. If the clock signal is missing, a data change is also not detected. 0 Data line is not active.
			- Synchronized: int: integer 1 The measurement is synchronized and the ratio is assumed realistic. That is, the clock and data lines are active and the following apples: NumErrors/NumBlock 0.1. 0 The measurement is not synchronized."""
		__meta_args_list = [
			ArgStruct.scalar_int('Num_Block'),
			ArgStruct.scalar_int('Num_Errors'),
			ArgStruct.scalar_float('Error_Rate'),
			ArgStruct.scalar_int('Meas_Finished'),
			ArgStruct.scalar_int('Clock_Detected'),
			ArgStruct.scalar_int('Data_Detected'),
			ArgStruct.scalar_int('Synchronized')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Num_Block: int = None
			self.Num_Errors: int = None
			self.Error_Rate: float = None
			self.Meas_Finished: int = None
			self.Clock_Detected: int = None
			self.Data_Detected: int = None
			self.Synchronized: int = None

	def get_result(self) -> ResultStruct:
		"""SCPI: BLER:RESult \n
		Snippet: value: ResultStruct = driver.bler.get_result() \n
		Queries the result of the last BLER measurement and responds with seven results, separated by commas.
		The first measurement following the start also queries intermediate results for the number of data bits, error bits and
		error rate. For method RsSmbv.Bler.Trigger.modeAUTO, only the final results of each single measurement are queried in the
		following measurements. Note: The restart of a new measurement is delayed until the first measurement result has been
		queried. The resulting brief measurement interruption is irrelevant because the subsequent measurement is synchronized
		within 24 data bits. \n
			:return: structure: for return value, see the help for ResultStruct structure arguments.
		"""
		return self._core.io.query_struct('BLER:RESult?', self.__class__.ResultStruct())

	def start(self) -> None:
		"""SCPI: BLER:STARt \n
		Snippet: driver.bler.start() \n
		Starts a continuous measurement. \n
		"""
		self._core.io.write(f'BLER:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BLER:STARt \n
		Snippet: driver.bler.start_with_opc() \n
		Starts a continuous measurement. \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BLER:STARt', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: BLER:STATe \n
		Snippet: value: bool = driver.bler.get_state() \n
		Activates/deactivates the measurement. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('BLER:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: BLER:STATe \n
		Snippet: driver.bler.set_state(state = False) \n
		Activates/deactivates the measurement. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'BLER:STATe {param}')

	def stop(self) -> None:
		"""SCPI: BLER:STOP \n
		Snippet: driver.bler.stop() \n
		Stops an ongoing measurement. \n
		"""
		self._core.io.write(f'BLER:STOP')

	def stop_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BLER:STOP \n
		Snippet: driver.bler.stop_with_opc() \n
		Stops an ongoing measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BLER:STOP', opc_timeout_ms)

	def set_store(self, filename: str) -> None:
		"""SCPI: BLER:STORe \n
		Snippet: driver.bler.set_store(filename = 'abc') \n
		Saves the current settings into the selected file; the file extension (*.ber_bler) is assigned automatically. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory. \n
			:param filename: 'filename' Filename or complete file path.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'BLER:STORe {param}')

	# noinspection PyTypeChecker
	def get_unit(self) -> enums.BertUnit:
		"""SCPI: BLER:UNIT \n
		Snippet: value: enums.BertUnit = driver.bler.get_unit() \n
		No command help available \n
			:return: unit: No help available
		"""
		response = self._core.io.query_str('BLER:UNIT?')
		return Conversions.str_to_scalar_enum(response, enums.BertUnit)

	def set_unit(self, unit: enums.BertUnit) -> None:
		"""SCPI: BLER:UNIT \n
		Snippet: driver.bler.set_unit(unit = enums.BertUnit.ENGineering) \n
		No command help available \n
			:param unit: No help available
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.BertUnit)
		self._core.io.write(f'BLER:UNIT {param}')

	def clone(self) -> 'BlerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BlerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PaCls:
	"""Pa commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pa", core, parent)

	def set(self, power: enums.EutraPdscPowA, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:PA \n
		Snippet: driver.source.bb.eutra.downlink.user.pa.set(power = enums.EutraPdscPowA._0, userIx = repcap.UserIx.Default) \n
		Sets PDSCH power factor according to , chapter 5.2. \n
			:param power: -6.02| -4.77| -3.01| -1.77| 0.97| 2.04| 3.01| 0
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(power, enums.EutraPdscPowA)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:PA {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.EutraPdscPowA:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:PA \n
		Snippet: value: enums.EutraPdscPowA = driver.source.bb.eutra.downlink.user.pa.get(userIx = repcap.UserIx.Default) \n
		Sets PDSCH power factor according to , chapter 5.2. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: power: -6.02| -4.77| -3.01| -1.77| 0.97| 2.04| 3.01| 0"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:PA?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPdscPowA)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RoscillatorCls:
	"""Roscillator commands group definition. 12 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("roscillator", core, parent)

	@property
	def external(self):
		"""external commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	@property
	def output(self):
		"""output commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def internal(self):
		"""internal commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_internal'):
			from .Internal import InternalCls
			self._internal = InternalCls(self._core, self._cmd_group)
		return self._internal

	def preset(self) -> None:
		"""SCPI: [SOURce]:ROSCillator:PRESet \n
		Snippet: driver.source.roscillator.preset() \n
		Resets the reference oscillator settings. \n
		"""
		self._core.io.write(f'SOURce:ROSCillator:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce]:ROSCillator:PRESet \n
		Snippet: driver.source.roscillator.preset_with_opc() \n
		Resets the reference oscillator settings. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:ROSCillator:PRESet', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.SourceInt:
		"""SCPI: [SOURce]:ROSCillator:SOURce \n
		Snippet: value: enums.SourceInt = driver.source.roscillator.get_source() \n
		Selects between internal or external reference frequency. \n
			:return: source: INTernal| EXTernal
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.SourceInt)

	def set_source(self, source: enums.SourceInt) -> None:
		"""SCPI: [SOURce]:ROSCillator:SOURce \n
		Snippet: driver.source.roscillator.set_source(source = enums.SourceInt.EXTernal) \n
		Selects between internal or external reference frequency. \n
			:param source: INTernal| EXTernal
		"""
		param = Conversions.enum_scalar_to_str(source, enums.SourceInt)
		self._core.io.write(f'SOURce:ROSCillator:SOURce {param}')

	def clone(self) -> 'RoscillatorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RoscillatorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TtimeCls:
	"""Ttime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ttime", core, parent)

	def set(self, ttime: float, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TTIMe \n
		Snippet: driver.source.bb.wlnn.fblock.ttime.set(ttime = 1.0, frameBlock = repcap.FrameBlock.Default) \n
		Sets the transition time when time domain windowing is active. The transition time defines the overlap range of two OFDM
		symbols. At a setting of 100 ns and if BW = 20 MHz, one sample overlaps. \n
			:param ttime: float Range: 0 to 1000 ns
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.decimal_value_to_str(ttime)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TTIMe {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:TTIMe \n
		Snippet: value: float = driver.source.bb.wlnn.fblock.ttime.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the transition time when time domain windowing is active. The transition time defines the overlap range of two OFDM
		symbols. At a setting of 100 ns and if BW = 20 MHz, one sample overlaps. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: ttime: float Range: 0 to 1000 ns"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:TTIMe?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PuschCls:
	"""Pusch commands group definition. 7 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pusch", core, parent)

	@property
	def ccoding(self):
		"""ccoding commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import CcodingCls
			self._ccoding = CcodingCls(self._core, self._cmd_group)
		return self._ccoding

	@property
	def harq(self):
		"""harq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import HarqCls
			self._harq = HarqCls(self._core, self._cmd_group)
		return self._harq

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBitsCls
			self._physBits = PhysBitsCls(self._core, self._cmd_group)
		return self._physBits

	@property
	def ri(self):
		"""ri commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ri'):
			from .Ri import RiCls
			self._ri = RiCls(self._core, self._cmd_group)
		return self._ri

	@property
	def ulsch(self):
		"""ulsch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ulsch'):
			from .Ulsch import UlschCls
			self._ulsch = UlschCls(self._core, self._cmd_group)
		return self._ulsch

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	def clone(self) -> 'PuschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PuschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InsertCls:
	"""Insert commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("insert", core, parent)

	def set(self, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:INSert \n
		Snippet: driver.source.bb.nfc.cblock.insert.set(commandBlock = repcap.CommandBlock.Default) \n
		Inserts a default command block before the selected command block. The command block with this position must be existing,
		otherwise an error is returned. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:INSert')

	def set_with_opc(self, commandBlock=repcap.CommandBlock.Default, opc_timeout_ms: int = -1) -> None:
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:INSert \n
		Snippet: driver.source.bb.nfc.cblock.insert.set_with_opc(commandBlock = repcap.CommandBlock.Default) \n
		Inserts a default command block before the selected command block. The command block with this position must be existing,
		otherwise an error is returned. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:INSert', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RampCls:
	"""Ramp commands group definition. 21 total commands, 5 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ramp", core, parent)

	@property
	def blank(self):
		"""blank commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_blank'):
			from .Blank import BlankCls
			self._blank = BlankCls(self._core, self._cmd_group)
		return self._blank

	@property
	def fall(self):
		"""fall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fall'):
			from .Fall import FallCls
			self._fall = FallCls(self._core, self._cmd_group)
		return self._fall

	@property
	def preSweep(self):
		"""preSweep commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_preSweep'):
			from .PreSweep import PreSweepCls
			self._preSweep = PreSweepCls(self._core, self._cmd_group)
		return self._preSweep

	@property
	def stair(self):
		"""stair commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_stair'):
			from .Stair import StairCls
			self._stair = StairCls(self._core, self._cmd_group)
		return self._stair

	@property
	def sweep(self):
		"""sweep commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	def get_attenuation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:ATTenuation \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_attenuation() \n
		No command help available \n
			:return: const_atten: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:ATTenuation?')
		return Conversions.str_to_float(response)

	def set_attenuation(self, const_atten: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:ATTenuation \n
		Snippet: driver.source.bb.pramp.ramp.set_attenuation(const_atten = 1.0) \n
		No command help available \n
			:param const_atten: No help available
		"""
		param = Conversions.decimal_value_to_str(const_atten)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:ATTenuation {param}')

	def get_constmode(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:CONStmode \n
		Snippet: value: bool = driver.source.bb.pramp.ramp.get_constmode() \n
		No command help available \n
			:return: constmode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:CONStmode?')
		return Conversions.str_to_bool(response)

	def set_constmode(self, constmode: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:CONStmode \n
		Snippet: driver.source.bb.pramp.ramp.set_constmode(constmode = False) \n
		No command help available \n
			:param constmode: No help available
		"""
		param = Conversions.bool_to_str(constmode)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:CONStmode {param}')

	def get_level(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:LEVel \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_level() \n
		No command help available \n
			:return: const_level: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:LEVel?')
		return Conversions.str_to_float(response)

	def get_range(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:RANGe \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_range() \n
		No command help available \n
			:return: range_py: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:RANGe?')
		return Conversions.str_to_float(response)

	def set_range(self, range_py: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:RANGe \n
		Snippet: driver.source.bb.pramp.ramp.set_range(range_py = 1.0) \n
		No command help available \n
			:param range_py: No help available
		"""
		param = Conversions.decimal_value_to_str(range_py)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:RANGe {param}')

	def get_resolution(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:RESolution \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_resolution() \n
		No command help available \n
			:return: power_resolution: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:RESolution?')
		return Conversions.str_to_float(response)

	def get_sample_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:SAMPlerate \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_sample_rate() \n
		No command help available \n
			:return: sample_rate: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:SAMPlerate?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_shape(self) -> enums.PowerRampShape:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:SHAPe \n
		Snippet: value: enums.PowerRampShape = driver.source.bb.pramp.ramp.get_shape() \n
		No command help available \n
			:return: shape: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:SHAPe?')
		return Conversions.str_to_scalar_enum(response, enums.PowerRampShape)

	def set_shape(self, shape: enums.PowerRampShape) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:SHAPe \n
		Snippet: driver.source.bb.pramp.ramp.set_shape(shape = enums.PowerRampShape.LINear) \n
		No command help available \n
			:param shape: No help available
		"""
		param = Conversions.enum_scalar_to_str(shape, enums.PowerRampShape)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:SHAPe {param}')

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.PowerRampSlope:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:SLOPe \n
		Snippet: value: enums.PowerRampSlope = driver.source.bb.pramp.ramp.get_slope() \n
		No command help available \n
			:return: slope: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.PowerRampSlope)

	def set_slope(self, slope: enums.PowerRampSlope) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:SLOPe \n
		Snippet: driver.source.bb.pramp.ramp.set_slope(slope = enums.PowerRampSlope.ASCending) \n
		No command help available \n
			:param slope: No help available
		"""
		param = Conversions.enum_scalar_to_str(slope, enums.PowerRampSlope)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:SLOPe {param}')

	def get_start_level(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:STARtlevel \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_start_level() \n
		No command help available \n
			:return: start_level: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:STARtlevel?')
		return Conversions.str_to_float(response)

	def get_stop_level(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:STOPlevel \n
		Snippet: value: float = driver.source.bb.pramp.ramp.get_stop_level() \n
		No command help available \n
			:return: stop_level: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:STOPlevel?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'RampCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RampCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PchannelCls:
	"""Pchannel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pchannel", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:PCHannel:STATe \n
		Snippet: value: bool = driver.source.bb.evdo.anetwork.pchannel.get_state() \n
		Displays the state of the pilot channel. Pilot channel is transmitted by sector on each active forward channel.
		It is present always and transmitted at the full sector power. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:PCHannel:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SspCls:
	"""Ssp commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ssp", core, parent)

	# noinspection PyTypeChecker
	def get_mpd_1(self) -> enums.EutraEmtcMpdcchNumRepetitions:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:MPD1 \n
		Snippet: value: enums.EutraEmtcMpdcchNumRepetitions = driver.source.bb.eutra.downlink.emtc.ssp.get_mpd_1() \n
		Sets the maximum number of MPDCCH repetitons for type 1 and type 2 common seach spaces. \n
			:return: max_rep_mpdcch_1: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:MPD1?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcMpdcchNumRepetitions)

	def set_mpd_1(self, max_rep_mpdcch_1: enums.EutraEmtcMpdcchNumRepetitions) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:MPD1 \n
		Snippet: driver.source.bb.eutra.downlink.emtc.ssp.set_mpd_1(max_rep_mpdcch_1 = enums.EutraEmtcMpdcchNumRepetitions._1) \n
		Sets the maximum number of MPDCCH repetitons for type 1 and type 2 common seach spaces. \n
			:param max_rep_mpdcch_1: 1| 2| 4| 8| 16| 32| 64| 128| 256
		"""
		param = Conversions.enum_scalar_to_str(max_rep_mpdcch_1, enums.EutraEmtcMpdcchNumRepetitions)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:MPD1 {param}')

	# noinspection PyTypeChecker
	def get_mpd_2(self) -> enums.EutraEmtcMpdcchNumRepetitions:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:MPD2 \n
		Snippet: value: enums.EutraEmtcMpdcchNumRepetitions = driver.source.bb.eutra.downlink.emtc.ssp.get_mpd_2() \n
		Sets the maximum number of MPDCCH repetitons for type 1 and type 2 common seach spaces. \n
			:return: max_rep_mpdcch_2: 1| 2| 4| 8| 16| 32| 64| 128| 256
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:MPD2?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcMpdcchNumRepetitions)

	def set_mpd_2(self, max_rep_mpdcch_2: enums.EutraEmtcMpdcchNumRepetitions) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:MPD2 \n
		Snippet: driver.source.bb.eutra.downlink.emtc.ssp.set_mpd_2(max_rep_mpdcch_2 = enums.EutraEmtcMpdcchNumRepetitions._1) \n
		Sets the maximum number of MPDCCH repetitons for type 1 and type 2 common seach spaces. \n
			:param max_rep_mpdcch_2: 1| 2| 4| 8| 16| 32| 64| 128| 256
		"""
		param = Conversions.enum_scalar_to_str(max_rep_mpdcch_2, enums.EutraEmtcMpdcchNumRepetitions)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:MPD2 {param}')

	# noinspection PyTypeChecker
	def get_pdsa(self) -> enums.EutraEmtcPdschNumRepetitions:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:PDSA \n
		Snippet: value: enums.EutraEmtcPdschNumRepetitions = driver.source.bb.eutra.downlink.emtc.ssp.get_pdsa() \n
		Sets the parameter pdsch-maxNumRepetitionCEmodeA that defines the PDSCH subframe assigment. \n
			:return: max_rep_pdscha: 16| 32| 64| NON| 192| 256| 384| 512| 786| 1024| 1536| 2048
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:PDSA?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcPdschNumRepetitions)

	def set_pdsa(self, max_rep_pdscha: enums.EutraEmtcPdschNumRepetitions) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:PDSA \n
		Snippet: driver.source.bb.eutra.downlink.emtc.ssp.set_pdsa(max_rep_pdscha = enums.EutraEmtcPdschNumRepetitions._1024) \n
		Sets the parameter pdsch-maxNumRepetitionCEmodeA that defines the PDSCH subframe assigment. \n
			:param max_rep_pdscha: 16| 32| 64| NON| 192| 256| 384| 512| 786| 1024| 1536| 2048
		"""
		param = Conversions.enum_scalar_to_str(max_rep_pdscha, enums.EutraEmtcPdschNumRepetitions)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:PDSA {param}')

	# noinspection PyTypeChecker
	def get_pdsb(self) -> enums.EutraEmtcPdschNumRepetitions:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:PDSB \n
		Snippet: value: enums.EutraEmtcPdschNumRepetitions = driver.source.bb.eutra.downlink.emtc.ssp.get_pdsb() \n
		Sets the parameter pdsch-maxNumRepetitionCEmodeB that defines the PDSCH subframe assigment. \n
			:return: max_rep_pdschb: 16| 32| 64| NON| 192| 256| 384| 512| 786| 1024| 1536| 2048
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:PDSB?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcPdschNumRepetitions)

	def set_pdsb(self, max_rep_pdschb: enums.EutraEmtcPdschNumRepetitions) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:PDSB \n
		Snippet: driver.source.bb.eutra.downlink.emtc.ssp.set_pdsb(max_rep_pdschb = enums.EutraEmtcPdschNumRepetitions._1024) \n
		Sets the parameter pdsch-maxNumRepetitionCEmodeB that defines the PDSCH subframe assigment. \n
			:param max_rep_pdschb: 16| 32| 64| NON| 192| 256| 384| 512| 786| 1024| 1536| 2048
		"""
		param = Conversions.enum_scalar_to_str(max_rep_pdschb, enums.EutraEmtcPdschNumRepetitions)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:PDSB {param}')

	# noinspection PyTypeChecker
	def get_stsf(self) -> enums.EutraEmtcMpdcchStartSf:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:STSF \n
		Snippet: value: enums.EutraEmtcMpdcchStartSf = driver.source.bb.eutra.downlink.emtc.ssp.get_stsf() \n
		Sets the start SF for the random access common search space. \n
			:return: sp_start_sf: S1| S1_5| S2| S2_5| S5| S8| S10| S20| S4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:STSF?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcMpdcchStartSf)

	def set_stsf(self, sp_start_sf: enums.EutraEmtcMpdcchStartSf) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:SSP:STSF \n
		Snippet: driver.source.bb.eutra.downlink.emtc.ssp.set_stsf(sp_start_sf = enums.EutraEmtcMpdcchStartSf.S1) \n
		Sets the start SF for the random access common search space. \n
			:param sp_start_sf: S1| S1_5| S2| S2_5| S5| S8| S10| S20| S4
		"""
		param = Conversions.enum_scalar_to_str(sp_start_sf, enums.EutraEmtcMpdcchStartSf)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:SSP:STSF {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ErgchCls:
	"""Ergch commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ergch", core, parent)

	@property
	def ctype(self):
		"""ctype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctype'):
			from .Ctype import CtypeCls
			self._ctype = CtypeCls(self._core, self._cmd_group)
		return self._ctype

	@property
	def dtau(self):
		"""dtau commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dtau'):
			from .Dtau import DtauCls
			self._dtau = DtauCls(self._core, self._cmd_group)
		return self._dtau

	@property
	def etau(self):
		"""etau commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_etau'):
			from .Etau import EtauCls
			self._etau = EtauCls(self._core, self._cmd_group)
		return self._etau

	@property
	def rgPattern(self):
		"""rgPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rgPattern'):
			from .RgPattern import RgPatternCls
			self._rgPattern = RgPatternCls(self._core, self._cmd_group)
		return self._rgPattern

	@property
	def ssIndex(self):
		"""ssIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssIndex'):
			from .SsIndex import SsIndexCls
			self._ssIndex = SsIndexCls(self._core, self._cmd_group)
		return self._ssIndex

	@property
	def ttiedch(self):
		"""ttiedch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttiedch'):
			from .Ttiedch import TtiedchCls
			self._ttiedch = TtiedchCls(self._core, self._cmd_group)
		return self._ttiedch

	def clone(self) -> 'ErgchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ErgchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UplinkCls:
	"""Uplink commands group definition. 169 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uplink", core, parent)

	@property
	def bwp(self):
		"""bwp commands group. 12 Sub-classes, 0 commands."""
		if not hasattr(self, '_bwp'):
			from .Bwp import BwpCls
			self._bwp = BwpCls(self._core, self._cmd_group)
		return self._bwp

	@property
	def nbwParts(self):
		"""nbwParts commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nbwParts'):
			from .NbwParts import NbwPartsCls
			self._nbwParts = NbwPartsCls(self._core, self._cmd_group)
		return self._nbwParts

	def clone(self) -> 'UplinkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UplinkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsetCls:
	"""Mset commands group definition. 13 total commands, 0 Subgroups, 13 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mset", core, parent)

	def get_boutput(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:BOUTput \n
		Snippet: value: bool = driver.source.bb.nfc.mset.get_boutput() \n
		When activated the signal at the baseband output changes between 0% and 100% voltage to be able to control the Reference
		Listeners. \n
			:return: boutput: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:BOUTput?')
		return Conversions.str_to_bool(response)

	def set_boutput(self, boutput: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:BOUTput \n
		Snippet: driver.source.bb.nfc.mset.set_boutput(boutput = False) \n
		When activated the signal at the baseband output changes between 0% and 100% voltage to be able to control the Reference
		Listeners. \n
			:param boutput: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(boutput)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:BOUTput {param}')

	def get_brate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:BRATe \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_brate() \n
		Returns the resulting bitrate for the current settings. \n
			:return: brate: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:BRATe?')
		return Conversions.str_to_float(response)

	def get_imodulation(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:IMODulation \n
		Snippet: value: bool = driver.source.bb.nfc.mset.get_imodulation() \n
		When selected, inverse modulation will be used. \n
			:return: imodulation: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:IMODulation?')
		return Conversions.str_to_bool(response)

	def set_imodulation(self, imodulation: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:IMODulation \n
		Snippet: driver.source.bb.nfc.mset.set_imodulation(imodulation = False) \n
		When selected, inverse modulation will be used. \n
			:param imodulation: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(imodulation)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:IMODulation {param}')

	def get_mdepth(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:MDEPth \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_mdepth() \n
		Sets the modulation depth in %. \n
			:return: mdepth: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mdepth(self, mdepth: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:MDEPth \n
		Snippet: driver.source.bb.nfc.mset.set_mdepth(mdepth = 1.0) \n
		Sets the modulation depth in %. \n
			:param mdepth: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(mdepth)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:MDEPth {param}')

	def get_mindex(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:MINDex \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_mindex() \n
		Defines the signal's modulation index in %. \n
			:return: mindex: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:MINDex?')
		return Conversions.str_to_float(response)

	def set_mindex(self, mindex: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:MINDex \n
		Snippet: driver.source.bb.nfc.mset.set_mindex(mindex = 1.0) \n
		Defines the signal's modulation index in %. \n
			:param mindex: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(mindex)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:MINDex {param}')

	def get_osrise(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:OSRise \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_osrise() \n
		Determines the size of the overshoot after the rising slope. \n
			:return: orise: float Range: 0 to 42
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:OSRise?')
		return Conversions.str_to_float(response)

	def set_osrise(self, orise: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:OSRise \n
		Snippet: driver.source.bb.nfc.mset.set_osrise(orise = 1.0) \n
		Determines the size of the overshoot after the rising slope. \n
			:param orise: float Range: 0 to 42
		"""
		param = Conversions.decimal_value_to_str(orise)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:OSRise {param}')

	def get_rcurve(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:RCURve \n
		Snippet: value: bool = driver.source.bb.nfc.mset.get_rcurve() \n
		When activated an 'RLC curve' is applied to the signal, otherwise a linear ramp is used. \n
			:return: rcurve: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:RCURve?')
		return Conversions.str_to_bool(response)

	def set_rcurve(self, rcurve: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:RCURve \n
		Snippet: driver.source.bb.nfc.mset.set_rcurve(rcurve = False) \n
		When activated an 'RLC curve' is applied to the signal, otherwise a linear ramp is used. \n
			:param rcurve: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(rcurve)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:RCURve {param}')

	def get_slope(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:SLOPe \n
		Snippet: value: bool = driver.source.bb.nfc.mset.get_slope() \n
		Determines the transition between the modulated and unmodulated parts (Edge/Slope) . \n
			:return: eslope: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:SLOPe?')
		return Conversions.str_to_bool(response)

	def set_slope(self, eslope: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:SLOPe \n
		Snippet: driver.source.bb.nfc.mset.set_slope(eslope = False) \n
		Determines the transition between the modulated and unmodulated parts (Edge/Slope) . \n
			:param eslope: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(eslope)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:SLOPe {param}')

	def get_symbol_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:SRATe \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_symbol_rate() \n
		Enters the sample rate, i.e. the time resolution of the generated signal. \n
			:return: srate: float Range: depends on protocol mode to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:SRATe?')
		return Conversions.str_to_float(response)

	def set_symbol_rate(self, srate: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:SRATe \n
		Snippet: driver.source.bb.nfc.mset.set_symbol_rate(srate = 1.0) \n
		Enters the sample rate, i.e. the time resolution of the generated signal. \n
			:param srate: float Range: depends on protocol mode to dynamic
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:SRATe {param}')

	def get_tfall(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TFALl \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_tfall() \n
		Defines the fall time (90 to 5 %) in us. \n
			:return: tfall: float Range: 0 to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:TFALl?')
		return Conversions.str_to_float(response)

	def set_tfall(self, tfall: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TFALl \n
		Snippet: driver.source.bb.nfc.mset.set_tfall(tfall = 1.0) \n
		Defines the fall time (90 to 5 %) in us. \n
			:param tfall: float Range: 0 to dynamic
		"""
		param = Conversions.decimal_value_to_str(tfall)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:TFALl {param}')

	def get_tlow(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TLOW \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_tlow() \n
		Defines the signals low time (below 5%) in us. \n
			:return: tlow: float Range: 0.4 to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:TLOW?')
		return Conversions.str_to_float(response)

	def set_tlow(self, tlow: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TLOW \n
		Snippet: driver.source.bb.nfc.mset.set_tlow(tlow = 1.0) \n
		Defines the signals low time (below 5%) in us. \n
			:param tlow: float Range: 0.4 to dynamic
		"""
		param = Conversions.decimal_value_to_str(tlow)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:TLOW {param}')

	def get_trise(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TRISe \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_trise() \n
		Defines the signals rise time (5 to 90 %) in us. \n
			:return: trise: float Range: dynamic to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:TRISe?')
		return Conversions.str_to_float(response)

	def set_trise(self, trise: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:TRISe \n
		Snippet: driver.source.bb.nfc.mset.set_trise(trise = 1.0) \n
		Defines the signals rise time (5 to 90 %) in us. \n
			:param trise: float Range: dynamic to dynamic
		"""
		param = Conversions.decimal_value_to_str(trise)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:TRISe {param}')

	def get_usfall(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:USFall \n
		Snippet: value: float = driver.source.bb.nfc.mset.get_usfall() \n
		Determines the size of the undershoot (ringing) after the falling slope. \n
			:return: ofall: float Range: 0 to 42
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:MSET:USFall?')
		return Conversions.str_to_float(response)

	def set_usfall(self, ofall: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:MSET:USFall \n
		Snippet: driver.source.bb.nfc.mset.set_usfall(ofall = 1.0) \n
		Determines the size of the undershoot (ringing) after the falling slope. \n
			:param ofall: float Range: 0 to 42
		"""
		param = Conversions.decimal_value_to_str(ofall)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:MSET:USFall {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PucchCls:
	"""Pucch commands group definition. 20 total commands, 15 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pucch", core, parent)

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import ConflictCls
			self._conflict = ConflictCls(self._core, self._cmd_group)
		return self._conflict

	@property
	def cqi(self):
		"""cqi commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cqi'):
			from .Cqi import CqiCls
			self._cqi = CqiCls(self._core, self._cmd_group)
		return self._cqi

	@property
	def cycShift(self):
		"""cycShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cycShift'):
			from .CycShift import CycShiftCls
			self._cycShift = CycShiftCls(self._core, self._cmd_group)
		return self._cycShift

	@property
	def dmr1(self):
		"""dmr1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmr1'):
			from .Dmr1 import Dmr1Cls
			self._dmr1 = Dmr1Cls(self._core, self._cmd_group)
		return self._dmr1

	@property
	def dmr2(self):
		"""dmr2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmr2'):
			from .Dmr2 import Dmr2Cls
			self._dmr2 = Dmr2Cls(self._core, self._cmd_group)
		return self._dmr2

	@property
	def harq(self):
		"""harq commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import HarqCls
			self._harq = HarqCls(self._core, self._cmd_group)
		return self._harq

	@property
	def mrb(self):
		"""mrb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mrb'):
			from .Mrb import MrbCls
			self._mrb = MrbCls(self._core, self._cmd_group)
		return self._mrb

	@property
	def napUsed(self):
		"""napUsed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_napUsed'):
			from .NapUsed import NapUsedCls
			self._napUsed = NapUsedCls(self._core, self._cmd_group)
		return self._napUsed

	@property
	def noc(self):
		"""noc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noc'):
			from .Noc import NocCls
			self._noc = NocCls(self._core, self._cmd_group)
		return self._noc

	@property
	def npar(self):
		"""npar commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_npar'):
			from .Npar import NparCls
			self._npar = NparCls(self._core, self._cmd_group)
		return self._npar

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBitsCls
			self._physBits = PhysBitsCls(self._core, self._cmd_group)
		return self._physBits

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def rbCount(self):
		"""rbCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbCount'):
			from .RbCount import RbCountCls
			self._rbCount = RbCountCls(self._core, self._cmd_group)
		return self._rbCount

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	def clone(self) -> 'PucchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PucchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GatingCls:
	"""Gating commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gating", core, parent)

	def set(self, gating: str, terminal=repcap.Terminal.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:GATing \n
		Snippet: driver.source.bb.evdo.terminal.ackChannel.gating.set(gating = rawAbc, terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Sets the active and inactive slots of the ACK channel.
		This parameter is in binary format and has a maximal length of 16 bits. The sequence starts at frame 0 and slot 0 and is
		repeated with the length of the pattern. A 0 gates the ACK channel off for the corresponding slot, a 1 activates the
		channel. \n
			:param gating: integer
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
		"""
		param = Conversions.value_to_str(gating)
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:GATing {param}')

	def get(self, terminal=repcap.Terminal.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:GATing \n
		Snippet: value: str = driver.source.bb.evdo.terminal.ackChannel.gating.get(terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Sets the active and inactive slots of the ACK channel.
		This parameter is in binary format and has a maximal length of 16 bits. The sequence starts at frame 0 and slot 0 and is
		repeated with the length of the pattern. A 0 gates the ACK channel off for the corresponding slot, a 1 activates the
		channel. \n
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:return: gating: integer"""
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:GATing?')
		return trim_str_response(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IsinCls:
	"""Isin commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("isin", core, parent)

	def set(self, inv_symb_ind: bool, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUSCh:ISIN \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pusch.isin.set(inv_symb_ind = False, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the 'Invalid Symbol Pattern Indicator' DCI field in DCI formats 0_1 and 0_2 on and off. \n
			:param inv_symb_ind: 1| ON| 0| OFF
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.bool_to_str(inv_symb_ind)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUSCh:ISIN {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUSCh:ISIN \n
		Snippet: value: bool = driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pusch.isin.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the 'Invalid Symbol Pattern Indicator' DCI field in DCI formats 0_1 and 0_2 on and off. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: inv_symb_ind: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUSCh:ISIN?')
		return Conversions.str_to_bool(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TselectedCls:
	"""Tselected commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tselected", core, parent)

	def get_catalog(self) -> str:
		"""SCPI: CALibration:TSELected:CATalog \n
		Snippet: value: str = driver.calibration.tselected.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('CALibration:TSELected:CATalog?')
		return trim_str_response(response)

	def get_step(self) -> str:
		"""SCPI: CALibration:TSELected:STEP \n
		Snippet: value: str = driver.calibration.tselected.get_step() \n
		No command help available \n
			:return: sel_string: No help available
		"""
		response = self._core.io.query_str('CALibration:TSELected:STEP?')
		return trim_str_response(response)

	def set_step(self, sel_string: str) -> None:
		"""SCPI: CALibration:TSELected:STEP \n
		Snippet: driver.calibration.tselected.set_step(sel_string = 'abc') \n
		No command help available \n
			:param sel_string: No help available
		"""
		param = Conversions.value_to_quoted_str(sel_string)
		self._core.io.write(f'CALibration:TSELected:STEP {param}')

	def get_measure(self) -> bool:
		"""SCPI: CALibration:TSELected:[MEASure] \n
		Snippet: value: bool = driver.calibration.tselected.get_measure() \n
		No command help available \n
			:return: meas: No help available
		"""
		response = self._core.io.query_str('CALibration:TSELected:MEASure?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RlobeCls:
	"""Rlobe commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rlobe", core, parent)

	def get_frequency(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:RLOBe:[FREQuency] \n
		Snippet: value: float = driver.source.bb.ils.localizer.rlobe.get_frequency() \n
		Sets the modulation frequency of the antenna lobe arranged at the right viewed from the air plane for the ILS localizer
		modulation signal. \n
			:return: frequency: float Range: 100 to 200
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:LOCalizer:RLOBe:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:LOCalizer:RLOBe:[FREQuency] \n
		Snippet: driver.source.bb.ils.localizer.rlobe.set_frequency(frequency = 1.0) \n
		Sets the modulation frequency of the antenna lobe arranged at the right viewed from the air plane for the ILS localizer
		modulation signal. \n
			:param frequency: float Range: 100 to 200
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:LOCalizer:RLOBe:FREQuency {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtchCls:
	"""Mtch commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtch", core, parent)

	# noinspection PyTypeChecker
	def get_csap(self) -> enums.EutraMtchSfAllPer:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MTCH:CSAP \n
		Snippet: value: enums.EutraMtchSfAllPer = driver.source.bb.eutra.downlink.mbsfn.mtch.get_csap() \n
		Defines the period during which resources corresponding with field commonSF-Alloc are divided between the (P) MCH that
		are configured for this MBSFN area. \n
			:return: alloc_period: AP4| AP8| AP16| AP32| AP64| AP128| AP256
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MTCH:CSAP?')
		return Conversions.str_to_scalar_enum(response, enums.EutraMtchSfAllPer)

	def set_csap(self, alloc_period: enums.EutraMtchSfAllPer) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MTCH:CSAP \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.mtch.set_csap(alloc_period = enums.EutraMtchSfAllPer.AP128) \n
		Defines the period during which resources corresponding with field commonSF-Alloc are divided between the (P) MCH that
		are configured for this MBSFN area. \n
			:param alloc_period: AP4| AP8| AP16| AP32| AP64| AP128| AP256
		"""
		param = Conversions.enum_scalar_to_str(alloc_period, enums.EutraMtchSfAllPer)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MTCH:CSAP {param}')

	def get_npmchs(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MTCH:NPMChs \n
		Snippet: value: int = driver.source.bb.eutra.downlink.mbsfn.mtch.get_npmchs() \n
		Defines the number of PMCHs in this MBSFN area. \n
			:return: num_of_pmchs: int Range: 1 to 15
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MTCH:NPMChs?')
		return Conversions.str_to_int(response)

	def set_npmchs(self, num_of_pmchs: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MTCH:NPMChs \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.mtch.set_npmchs(num_of_pmchs = 1) \n
		Defines the number of PMCHs in this MBSFN area. \n
			:param num_of_pmchs: int Range: 1 to 15
		"""
		param = Conversions.decimal_value_to_str(num_of_pmchs)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MTCH:NPMChs {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.EutraUlFrc, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:FRC:TYPE \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.frc.typePy.set(type_py = enums.EutraUlFrc.A11, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects a predefined fixed reference channel according to and . \n
			:param type_py: A11| A12| A13| A14| A15| A21| A22| A23| A31| A32| A33| A34| A35| A36| A37| A41| A42| A43| A44| A45| A46| A47| A48| A51| A52| A53| A54| A55| A56| A57| A71| A72| A73| A74| A75| A76| A81| A82| A83| A84| A85| A86| UE11| UE12| UE21| UE22| UE3| A16| A17| A121| A122| A123| A124| A125| A126| A131| A132| A133| A134| A135| A136 | A171| A172| A173| A174| A175| A176| A181| A182| A183| A184| A185| A186| A191| A192| A193| A194| A195| A196| A211| A212| A213| A214| A215| A216| A221| A222| A223| A224
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.EutraUlFrc)
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:FRC:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> enums.EutraUlFrc:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:FRC:TYPE \n
		Snippet: value: enums.EutraUlFrc = driver.source.bb.eutra.uplink.ue.cell.frc.typePy.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects a predefined fixed reference channel according to and . \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: type_py: A11| A12| A13| A14| A15| A21| A22| A23| A31| A32| A33| A34| A35| A36| A37| A41| A42| A43| A44| A45| A46| A47| A48| A51| A52| A53| A54| A55| A56| A57| A71| A72| A73| A74| A75| A76| A81| A82| A83| A84| A85| A86| UE11| UE12| UE21| UE22| UE3| A16| A17| A121| A122| A123| A124| A125| A126| A131| A132| A133| A134| A135| A136 | A171| A172| A173| A174| A175| A176| A181| A182| A183| A184| A185| A186| A191| A192| A193| A194| A195| A196| A211| A212| A213| A214| A215| A216| A221| A222| A223| A224"""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:FRC:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraUlFrc)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClippingCls:
	"""Clipping commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clipping", core, parent)

	def get_cfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:CFACtor \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.clipping.get_cfactor() \n
		Sets the value of the desired crest factor, if baseband clipping is enabled. A target crest factor above the crest factor
		of the unclipped multicarrier signal has no effect. \n
			:return: cfactor: float Range: -50 to 50, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:CFACtor?')
		return Conversions.str_to_float(response)

	def set_cfactor(self, cfactor: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:CFACtor \n
		Snippet: driver.source.bb.arbitrary.mcarrier.clipping.set_cfactor(cfactor = 1.0) \n
		Sets the value of the desired crest factor, if baseband clipping is enabled. A target crest factor above the crest factor
		of the unclipped multicarrier signal has no effect. \n
			:param cfactor: float Range: -50 to 50, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(cfactor)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:CFACtor {param}')

	def get_cutoff(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:CUToff \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.clipping.get_cutoff() \n
		Sets the cutoff frequency of the final low pass filter, if baseband clipping is enabled. \n
			:return: cutoff: float Range: 0 to 250E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:CUToff?')
		return Conversions.str_to_float(response)

	def set_cutoff(self, cutoff: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:CUToff \n
		Snippet: driver.source.bb.arbitrary.mcarrier.clipping.set_cutoff(cutoff = 1.0) \n
		Sets the cutoff frequency of the final low pass filter, if baseband clipping is enabled. \n
			:param cutoff: float Range: 0 to 250E6
		"""
		param = Conversions.decimal_value_to_str(cutoff)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:CUToff {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:[STATe] \n
		Snippet: value: bool = driver.source.bb.arbitrary.mcarrier.clipping.get_state() \n
		Switches baseband clipping on and off. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CLIPping:[STATe] \n
		Snippet: driver.source.bb.arbitrary.mcarrier.clipping.set_state(state = False) \n
		Switches baseband clipping on and off. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CLIPping:STATe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LffSweepCls:
	"""LffSweep commands group definition. 4 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lffSweep", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import ImmediateCls
			self._immediate = ImmediateCls(self._core, self._cmd_group)
		return self._immediate

	@property
	def source(self):
		"""source commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	def set(self, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: TRIGger<HW>:LFFSweep \n
		Snippet: driver.trigger.lffSweep.set(inputIx = repcap.InputIx.Default) \n
			INTRO_CMD_HELP: Executes an LF frequency sweep in the following configuration: \n
			- method RsSmbv.Trigger.LffSweep.Source.set SING
			- LFO:SWE:MODE AUTO \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'TRIGger{inputIx_cmd_val}:LFFSweep')

	def set_with_opc(self, inputIx=repcap.InputIx.Default, opc_timeout_ms: int = -1) -> None:
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		"""SCPI: TRIGger<HW>:LFFSweep \n
		Snippet: driver.trigger.lffSweep.set_with_opc(inputIx = repcap.InputIx.Default) \n
			INTRO_CMD_HELP: Executes an LF frequency sweep in the following configuration: \n
			- method RsSmbv.Trigger.LffSweep.Source.set SING
			- LFO:SWE:MODE AUTO \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'TRIGger{inputIx_cmd_val}:LFFSweep', opc_timeout_ms)

	def clone(self) -> 'LffSweepCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LffSweepCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SensitivityCls:
	"""Sensitivity commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sensitivity", core, parent)

	def get(self, generatorIx=repcap.GeneratorIx.Default) -> float:
		"""SCPI: [SOURce<HW>]:AM<CH>:SENSitivity \n
		Snippet: value: float = driver.source.am.sensitivity.get(generatorIx = repcap.GeneratorIx.Default) \n
		Sets the sensitivity of the external signal source for amplitude modulation in %/V. \n
			:param generatorIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Am')
			:return: sensitivity: float Range: 0 to 100"""
		generatorIx_cmd_val = self._cmd_group.get_repcap_cmd_value(generatorIx, repcap.GeneratorIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AM{generatorIx_cmd_val}:SENSitivity?')
		return Conversions.str_to_float(response)
